@@ -1,10 +1,10 @@
 #include <stdio.h>
 #include <mgl2/mpi.h>
 #include <mpi.h>
-#define MCW		MPI_COMM_WORLD
 
 int main(int argc, char *argv[])
 {
+	mgl_textdomain(argv?argv[0]:NULL);
 	// initialize MPI
 	int rank=0, numproc=1;
 	MPI_Init(&argc, &argv);
