@@ -484,7 +484,7 @@ public:
 	/// Set to use or not text rotation
 	inline void SetRotatedText(bool val)	{	set(val,MGL_ENABLE_RTEXT);	}
 	/// Set default font style and color
-	void SetFontDef(const char *font);
+	inline void SetFontDef(const char *font){	mgl_strncpy(FontDef, font, 31);	}
 	/// Set to use or not text rotation
 	inline void SetTickRotate(bool val)	{	set(val,MGL_TICKS_ROTATE);	}
 	/// Set to use or not text rotation
@@ -509,8 +509,8 @@ public:
 	long CopyNtoC(long k, mreal c);
 	long CopyProj(long from, mglPoint p, mglPoint n, short sub=0);
 	void SetRGBA(long k, const mglColor &c)
-	{	mglPnt &p=Pnt[k];	p.r = c.r;	p.g = c.g;	p.b = c.b;	p.a = c.a;	}
-	virtual void Reserve(long n);		///< Allocate n-cells for Pnt and return current position
+	{	if(k>=0)	{mglPnt &p=Pnt[k];	p.r = c.r;	p.g = c.g;	p.b = c.b;	p.a = c.a;}	}
+	virtual void Reserve(long n);	///< Allocate n-cells for Pnt and return current position
 	/// Set to reduce accuracy of points (to reduce size of output files)
 	inline void SetReduceAcc(bool val)	{	set(val, MGL_REDUCEACC);	}
 	/// Add glyph of current font to the Glf and return its position
@@ -658,7 +658,7 @@ protected:
 	long CurrPal;		///< Current palette index
 	mreal MarkSize;		///< The size of marks for 1D plots.
 	mreal ArrowSize;	///< The size of arrows.
-	char last_style[64];///< Last pen style
+	char last_style[64];///< Last pen style	TODO: replace by std::string
 	mreal font_factor;	///< Font scaling factor
 
 	long dr_x, dr_y, dr_p;	///< default drawing region for quality&4 mode
