@@ -1,6 +1,6 @@
 /***************************************************************************
  * fltk.h is part of Math Graphic Library
- * Copyright (C) 2007-2014 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
+ * Copyright (C) 2007-2016 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU Library General Public License as       *
@@ -35,6 +35,8 @@ int MGL_EXPORT mgl_fltk_run_();
 int MGL_EXPORT mgl_fltk_thr();
 /// Callback function for asking user.
 void MGL_EXPORT mgl_ask_fltk(const wchar_t *quest, wchar_t *res);
+/// Return pointer to widget (Fl_MGLView*) used for plotting
+MGL_EXPORT void *mgl_fltk_widget(HMGL gr);
 #ifdef __cplusplus
 }
 //-----------------------------------------------------------------------------
@@ -43,7 +45,7 @@ void MGL_EXPORT mgl_ask_fltk(const wchar_t *quest, wchar_t *res);
 /// Wrapper class for windows displaying graphics
 class MGL_EXPORT mglFLTK : public mglWnd
 {
-	mglFLTK(const mglFLTK &t) {}	// copying is not allowed
+	mglFLTK(const mglFLTK &) {}	// copying is not allowed
 	const mglFLTK &operator=(const mglFLTK &t)	{	return t;	}
 public:
 	mglFLTK(const char *title="MathGL") : mglWnd()
@@ -61,6 +63,8 @@ public:
     virtual ~mglFLTK() {}
 	int Run()	{	return mgl_fltk_run();	}	///< Run main loop for event handling
 	int RunThr()	{	return mgl_fltk_thr();	}	///< Run main loop for event handling in separate thread
+	/// Return pointer to widget (Fl_MGLView*) used for plotting
+	void *Widget()	{	return mgl_fltk_widget(gr);	}
 };
 //-----------------------------------------------------------------------------
 #endif
