@@ -1,6 +1,6 @@
 /***************************************************************************
  * wnd.h is part of Math Graphic Library
- * Copyright (C) 2007-2014 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
+ * Copyright (C) 2007-2016 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU Library General Public License as       *
@@ -33,7 +33,7 @@ public:
 	virtual void Reload(){}		///< Function for reloading data
 	virtual void Click() {}		///< Callback function on mouse click
 #if MGL_HAVE_PTHR_WIDGET
-	mglDraw()	{	running=false;	pthread_mutex_init(&mutex,NULL);	}
+	mglDraw()	{	running=false;	pthread_mutex_init(&mutex,NULL);	thr=0;	}
 	virtual ~mglDraw()	{	pthread_mutex_destroy(&mutex);	}
 
 	virtual void Calc()	{}		///< Function for calculations
@@ -56,7 +56,7 @@ public:
 	pthread_t thr;
 	bool running;
 	pthread_mutex_t mutex;
-	
+
 #else
 	mglDraw() {}
 	virtual ~mglDraw() {}
@@ -74,12 +74,14 @@ void MGL_EXPORT mgl_reload_class(void *p);
 /// Abstract class for windows displaying graphics
 class MGL_EXPORT mglWnd : public mglGraph
 {
-	mglWnd(const mglWnd &t) {}	// copying is not allowed
+	mglWnd(const mglWnd &) {}	// copying is not allowed
 	const mglWnd &operator=(const mglWnd &t)	{	return t;	}
 public:
 	mglWnd() : mglGraph(-1)	{}
 	virtual ~mglWnd() {	mgl_use_graph(gr,-255);	}
 	virtual int Run()=0;		///< Run main loop for event handling
+	/// Return pointer to widget used for plotting
+	virtual void *Widget()	{	return NULL;	}
 
 	inline void ToggleAlpha()	///< Switch on/off transparency (do not overwrite user settings)
 	{	mgl_wnd_toggle_alpha(gr);	}
