@@ -362,7 +362,7 @@ void mglCanvas::mark_plot(long p, char type, mreal size)
 	size *= MarkSize*0.35*font_factor;
 	if(type=='.')	size = fabs(PenWidth)*sqrt(font_factor/400);
 	if(TernAxis&12) for(int i=0;i<4;i++)
-	{	p = ProjScale(i, pp);	MGL_MARK_PLOT	}
+	{	p = ProjScale(i, pp);	if(p>=0)	{MGL_MARK_PLOT}	}
 	else	{	MGL_MARK_PLOT	}
 }
 //-----------------------------------------------------------------------------
@@ -377,13 +377,22 @@ void mglCanvas::line_plot(long p1, long p2)
 	if(p1<0 || p2<0 || mgl_isnan(Pnt[p1].x) || mgl_isnan(Pnt[p2].x) || SamePnt(p1,p2))	return;
 	if(p1>p2)	{	long kk=p1;	p1=p2;	p2=kk;	}	// rearrange start/end for proper dashing
 	long pp1=p1,pp2=p2;
-	mreal pw = fabs(PenWidth)*sqrt(font_factor/400);
+	mreal pw = fabs(PenWidth)*sqrt(font_factor/400), d=0;
 	if(TernAxis&12) for(int i=0;i<4;i++)
 	{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);
-		MGL_LINE_PLOT	}
-	else	{	MGL_LINE_PLOT	}
-	mreal d = hypot(Pnt[p1].x-Pnt[p2].x, Pnt[p1].y-Pnt[p2].y);
-	pPos = fmod(pPos+d/pw/1.5, 16);
+		if(p1>=0&&p2>=0)
+		{
+			d += hypot(Pnt[p1].x-Pnt[p2].x, Pnt[p1].y-Pnt[p2].y);
+			MGL_LINE_PLOT
+			pPos = fmod(pPos+d/pw/1.5, 16);
+		}
+	}
+	else
+	{
+		d = hypot(Pnt[p1].x-Pnt[p2].x, Pnt[p1].y-Pnt[p2].y);
+		MGL_LINE_PLOT
+		pPos = fmod(pPos+d/pw/1.5, 16);
+	}
 }
 //-----------------------------------------------------------------------------
 #define MGL_TRIG_PLOT	if(Quality&MGL_DRAW_LMEM)	\
@@ -399,7 +408,7 @@ void mglCanvas::trig_plot(long p1, long p2, long p3)
 	mreal pw = fabs(PenWidth)*sqrt(font_factor/400);
 	if(TernAxis&12) for(int i=0;i<4;i++)
 	{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);
-		p3 = ProjScale(i, pp3);	MGL_TRIG_PLOT	}
+		p3 = ProjScale(i, pp3);	if(p1>=0&&p2>=0&&p3>=0)	{MGL_TRIG_PLOT}	}
 	else	{	MGL_TRIG_PLOT	}
 }
 //-----------------------------------------------------------------------------
@@ -419,7 +428,7 @@ void mglCanvas::quad_plot(long p1, long p2, long p3, long p4)
 	if(TernAxis&12) for(int i=0;i<4;i++)
 	{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);
 		p3 = ProjScale(i, pp3);	p4 = ProjScale(i, pp4);
-		MGL_QUAD_PLOT	}
+		if(p1>=0&&p2>=0&&p3>=0&&p4>=0)	{MGL_QUAD_PLOT}	}
 	else	{	MGL_QUAD_PLOT	}
 }
 //-----------------------------------------------------------------------------
@@ -1169,7 +1178,7 @@ void mglCanvas::StartAutoGroup (const char *lbl)
 	if(grp_counter>1)	return;	// do nothing in "subgroups"
 	if(ObjId<0)	{	ObjId = -id;	id++;	}
 	size_t len = Grp.size();
-	if(ObjId>=0 && len>0 && ObjId!=Grp[len-1].Id)
+	if(ObjId>=0 && (len==0 || (len>0 && ObjId!=Grp[len-1].Id)))
 #pragma omp critical(grp)
 	{	MGL_PUSH(Grp,mglGroup(lbl,ObjId),mutexGrp);}
 	else if(ObjId<0)
@@ -1206,3 +1215,15 @@ void mglCanvas::Push()
 	{MGL_PUSH(stack,B,mutexStk);}
 }
 //-----------------------------------------------------------------------------
+void mglCanvas::Pop()
+{
+	B = stack.back(); 
+#if MGL_HAVE_PTHREAD
+	pthread_mutex_lock(&m);
+	stack.pop_back();
+	pthread_mutex_unlock(&m);
+#else
+#pragma omp critical(stk)
+	stack.pop_back();
+#endif
+}
