@@ -46,7 +46,7 @@ void MGL_EXPORT mgl_puts_fit(HMGL gr, double x, double y, double z, const char *
 	long n = strlen(mglFitRes)+(pre?strlen(pre):0)+1;
 	char *buf = new char[n];
 	if(pre)	snprintf(buf,n,"%s%s",pre,mglFitRes);
-	else	strncpy(buf,mglFitRes,n);
+	else	mgl_strncpy(buf,mglFitRes,n);
 	buf[n-1]=0;	mgl_puts(gr,x,y,z,buf,font,size);
 	delete []buf;
 }
@@ -371,7 +371,7 @@ HMDT MGL_EXPORT mgl_fit_xyzs(HMGL gr, HCDT xx, HCDT yy, HCDT zz, HCDT ss, const
 	mglData x(m, n), y(m, n), z(zz), s(ss);	x.s=L"x";	y.s=L"y";
 	long nz = zz->GetNz(), mm = n*m;
 #pragma omp parallel for collapse(2)
-	for(long i=0;i<m;i++)	for(long j=0;j<n;j++)
+	for(long j=0;j<n;j++)	for(long i=0;i<m;i++)
 	{
 		long i0 = i+m*j;
 		x.a[i0] = GetX(xx,i,j,0).x;
@@ -417,7 +417,7 @@ HMDT MGL_EXPORT mgl_fit_xyzas(HMGL gr, HCDT xx, HCDT yy, HCDT zz, HCDT aa, HCDT
 	mglData x(m,n,l), y(m,n,l), z(m,n,l), a(aa), s(ss);
 	x.s=L"x";	y.s=L"y";	z.s=L"z";
 #pragma omp parallel for collapse(3)
-	for(long i=0;i<m;i++)	for(long j=0;j<n;j++)	for(long k=0;k<l;k++)
+	for(long k=0;k<l;k++)	for(long j=0;j<n;j++)	for(long i=0;i<m;i++)
 	{
 		long i0 = i+m*(j+n*k);
 		x.a[i0] = GetX(xx,i,j,k).x;
@@ -516,7 +516,7 @@ MGL_EXPORT const char *mgl_get_fit(HMGL )	{	return mglFitRes;	}
 int MGL_EXPORT mgl_get_fit_(uintptr_t *gr, char *out, int len)
 {
 	const char *res = mgl_get_fit(_GR_);
-	if(out)	strncpy(out,res,len);
+	if(out)	mgl_strncpy(out,res,len);
 	return strlen(res);
 }
 //-----------------------------------------------------------------------------
