@@ -2,7 +2,6 @@
 template <class Treal> Treal mglLineart(const Treal *a, long nx, long ny, long nz, mreal x, mreal y, mreal z)
 {
 	if(!a || nx<1 || ny<1 || nz<1)	return 0;
-	register long i0;
 	Treal b=0,dx,dy,dz,b1,b0;
 	if(x<0 || y<0 || z<0 || x>nx-1 || y>ny-1 || z>nz-1)
 		return 0;
@@ -11,7 +10,7 @@ template <class Treal> Treal mglLineart(const Treal *a, long nx, long ny, long n
 		long kx=long(x), ky=long(y), kz=long(z);
 		dx = x-mreal(kx);	dy = y-mreal(ky);	dz = z-mreal(kz);
 
-		i0 = kx+nx*(ky+ny*kz);
+		long i0 = kx+nx*(ky+ny*kz);
 		b0 = a[i0]*(mreal(1)-dx-dy+dx*dy) + dx*(mreal(1)-dy)*a[i0+1] +
 			dy*(mreal(1)-dx)*a[i0+nx] + dx*dy*a[i0+nx+1];
 		i0 = kx+nx*(ky+ny*(kz+1));
@@ -23,7 +22,7 @@ template <class Treal> Treal mglLineart(const Treal *a, long nx, long ny, long n
 	{
 		long kx=long(x), ky=long(y);
 		dx = x-kx;	dy=y-ky;
-		i0 = kx+nx*ky;
+		long i0 = kx+nx*ky;
 		b = a[i0]*(mreal(1)-dx-dy+dx*dy) + dx*(mreal(1)-dy)*a[i0+1] +
 			dy*(mreal(1)-dx)*a[i0+nx] + dx*dy*a[i0+nx+1];
 	}
@@ -39,22 +38,20 @@ template <class Treal> Treal mglLineart(const Treal *a, long nx, long ny, long n
 //-----------------------------------------------------------------------------
 template <class Treal> Treal mgl_spline3t(const Treal y[4], long n, mreal dx, Treal &dy)
 {
-	Treal d[3], t0,t1, f0,d0;
+	Treal d[3];
 	d[0] = -(y[2]-mreal(4)*y[1]+mreal(3)*y[0])/mreal(2);
 	d[1] = (y[2]-y[0])/mreal(2);
 	d[2] = (y[3]-y[1])/mreal(2);
-//	d[3] = (mreal(3)*y[3]-mreal(4)*y[2]+y[1])/mreal(2);
 
-	t0 = (y[2]+y[0])/mreal(2)-y[1];
-	t1 = (y[3]+y[1])/mreal(2)-y[2];
-	f0 = y[n];		d0 = d[n];
-	Treal res = 0;
+	Treal t0 = (y[2]+y[0])/mreal(2)-y[1];
+	Treal t1 = (y[3]+y[1])/mreal(2)-y[2];
+	Treal f0 = y[n], d0 = d[n], res = 0;
 	if(n==1)
 	{
-		Treal f1 = y[2], d1 = d[2];
-		Treal b3 = mreal(10)*(f1-f0)+t1-mreal(3)*t0-mreal(4)*d1-mreal(6)*d0;
-		Treal b4 = mreal(15)*(f0-f1)-mreal(2)*t1+mreal(3)*t0+mreal(7)*d1+mreal(8)*d0;
-		Treal b5 = mreal(6)*(f1-f0)+t1-t0-mreal(3)*d1-mreal(3)*d0;
+		Treal df = y[2]-f0, d1 = d[2];
+		Treal b3 = mreal(10)*df+t1-mreal(3)*t0-mreal(4)*d1-mreal(6)*d0;
+		Treal b4 = mreal(-15)*df-mreal(2)*t1+mreal(3)*t0+mreal(7)*d1+mreal(8)*d0;
+		Treal b5 = mreal(6)*df+t1-t0-mreal(3)*d1-mreal(3)*d0;
 		dy = d0 + dx*(mreal(2)*t0+dx*(mreal(3)*b3+dx*(mreal(4)*b4+dx*mreal(5)*b5)));
 //		d2y = mreal(2)*t0 + dx*(mreal(6)*b3+dx*(mreal(12)*b4+dx*mreal(20)*b5));	// 2nd derivative for future
 		res = f0 + dx*(d0+dx*(t0+dx*(b3+dx*(b4+dx*b5))));
@@ -68,22 +65,20 @@ template <class Treal> Treal mgl_spline3t(const Treal y[4], long n, mreal dx, Tr
 //-----------------------------------------------------------------------------
 template <class Treal> Treal mgl_spline3st(const Treal y[4], long n, mreal dx)
 {
-	Treal d[3], t0,t1, f0,d0;
+	Treal d[3];
 	d[0] = -(y[2]-mreal(4)*y[1]+mreal(3)*y[0])/mreal(2);
 	d[1] = (y[2]-y[0])/mreal(2);
 	d[2] = (y[3]-y[1])/mreal(2);
-//	d[3] = (mreal(3)*y[3]-mreal(4)*y[2]+y[1])/mreal(2);
 
-	Treal res;
-	f0 = y[n];		d0 = d[n];
-	t0 = (y[2]+y[0])/mreal(2)-y[1];
-	t1 = (y[3]+y[1])/mreal(2)-y[2];
+	Treal f0 = y[n], d0 = d[n], res;
+	Treal t0 = (y[2]+y[0])/mreal(2)-y[1];
+	Treal t1 = (y[3]+y[1])/mreal(2)-y[2];
 	if(n==1)
 	{
-		Treal f1 = y[2], d1 = d[2];
-		Treal b3 = mreal(10)*(f1-f0)+t1-mreal(3)*t0-mreal(4)*d1-mreal(6)*d0;
-		Treal b4 = mreal(15)*(f0-f1)-mreal(2)*t1+mreal(3)*t0+mreal(7)*d1+mreal(8)*d0;
-		Treal b5 = mreal(6)*(f1-f0)+t1-t0-mreal(3)*d1-mreal(3)*d0;
+		Treal df = y[2]-f0, d1 = d[2];
+		Treal b3 = mreal(10)*df+t1-mreal(3)*t0-mreal(4)*d1-mreal(6)*d0;
+		Treal b4 = mreal(-15)*df-mreal(2)*t1+mreal(3)*t0+mreal(7)*d1+mreal(8)*d0;
+		Treal b5 = mreal(6)*df+t1-t0-mreal(3)*d1-mreal(3)*d0;
 		res = f0 + dx*(d0+dx*(t0+dx*(b3+dx*(b4+dx*b5))));
 	}
 	else	res = f0 + dx*(d0+dx*(n<1?t0:t1));
@@ -95,7 +90,7 @@ template <class Treal> Treal mglSpline1t(const Treal *a, long nx, mreal x, Treal
 	Treal r,d;
 	if(nx>3)
 	{
-		register long k = long(x);
+		long k = long(x);
 		if(k>0 && k<nx-2)	r = mgl_spline3t<Treal>(a+k-1, 1, x-k, d);
 		else if(k<1)		r = mgl_spline3t<Treal>(a, 0, x, d);
 		else	r = mgl_spline3t<Treal>(a+nx-4, 2, x+2-nx, d);
@@ -116,7 +111,7 @@ template <class Treal> Treal mglSpline1st(const Treal *a, long nx, mreal x)
 	Treal r;
 	if(nx>3)
 	{
-		register long k = long(x);
+		long k = long(x);
 		if(k>0 && k<nx-2)	r = mgl_spline3st<Treal>(a+k-1, 1, x-k);
 		else if(k<1)		r = mgl_spline3st<Treal>(a, 0, x);
 		else	r = mgl_spline3st<Treal>(a+nx-4, 2, x+2-nx);
@@ -177,7 +172,9 @@ template <class Treal> Treal mglSpline3t(const Treal *a, long nx, long ny, long
 	}
 	else	// 1d interpolation
 		b = mglSpline1t<Treal>(a,nx,x,&gx);
-	if(dx)	*dx=gx;	if(dy)	*dy=gy;	if(dz)	*dz=gz;
+	if(dx)	*dx=gx;
+	if(dy)	*dy=gy;
+	if(dz)	*dz=gz;
 	return b;
 }
 //-----------------------------------------------------------------------------
