@@ -24,6 +24,8 @@
 #include "mgl2/data.h"
 #include "mgl2/base.h"
 //-----------------------------------------------------------------------------
+void MGL_NO_EXPORT mgl_surf_gen(HMGL gr, HCDT x, HCDT y, HCDT z, HCDT c, HCDT a, const char *sch);
+//-----------------------------------------------------------------------------
 HCDT MGL_NO_EXPORT fill_slice_x(HMGL gr, double sv, HCDT a, mglDataV &xx, mglDataV &yy, mglDataV &zz, mglData &aa)
 {
 	long n=a->GetNx(),m=a->GetNy(),l=a->GetNz();
@@ -105,7 +107,7 @@ void MGL_EXPORT mgl_dens_x(HMGL gr, HCDT a, const char *sch, double sv, const ch
 	if(sv<gr->Min.x || sv>gr->Max.x)	{	gr->SetWarn(mglWarnSlc,"DensX");	gr->LoadState();	return;	}
 	mglDataV xx,yy,zz;	mglData aa;
 	a = fill_slice_x(gr,sv,a,xx,yy,zz,aa);
-	mgl_surfc_xy(gr,&xx,&yy,&zz,a,sch,0);
+	mgl_surf_gen(gr, &xx,&yy,&zz,a, 0, sch);
 }
 //-----------------------------------------------------------------------------
 void MGL_EXPORT mgl_dens_y(HMGL gr, HCDT a, const char *sch, double sv, const char *opt)
@@ -117,7 +119,7 @@ void MGL_EXPORT mgl_dens_y(HMGL gr, HCDT a, const char *sch, double sv, const ch
 	if(sv<gr->Min.y || sv>gr->Max.y)	{	gr->SetWarn(mglWarnSlc,"DensY");	gr->LoadState();	return;	}
 	mglDataV xx,yy,zz;	mglData aa;
 	a = fill_slice_y(gr,sv,a,xx,yy,zz,aa);
-	mgl_surfc_xy(gr,&xx,&yy,&zz,a,sch,0);
+	mgl_surf_gen(gr, &xx,&yy,&zz,a, 0, sch);
 }
 //-----------------------------------------------------------------------------
 void MGL_EXPORT mgl_dens_z(HMGL gr, HCDT a, const char *sch, double sv, const char *opt)
@@ -129,7 +131,7 @@ void MGL_EXPORT mgl_dens_z(HMGL gr, HCDT a, const char *sch, double sv, const ch
 	if(sv<gr->Min.z || sv>gr->Max.z)	{	gr->SetWarn(mglWarnSlc,"DensZ");	gr->LoadState();	return;	}
 	mglDataV xx,yy,zz;	mglData aa;
 	a = fill_slice_z(gr,sv,a,xx,yy,zz,aa);
-	mgl_surfc_xy(gr,&xx,&yy,&zz,a,sch,0);
+	mgl_surf_gen(gr, &xx,&yy,&zz,a, 0, sch);
 }
 //-----------------------------------------------------------------------------
 void MGL_EXPORT mgl_dens_x_(uintptr_t *gr, uintptr_t *a, const char *sch, mreal *sv, const char *opt,int l,int lo)
@@ -174,7 +176,7 @@ void MGL_EXPORT mgl_cont_x_val(HMGL gr, HCDT v, HCDT a, const char *sch, double
 #pragma omp parallel for
 	for(long i=0;i<v->GetNx();i++)
 	{
-		register mreal v0 = v->v(i);
+		mreal v0 = v->v(i);
 		mgl_cont_gen(gr,v0,a,&xx,&yy,&zz,gr->GetC(ss,v0),text,0);
 	}
 	gr->EndGroup();
@@ -200,7 +202,7 @@ void MGL_EXPORT mgl_cont_y_val(HMGL gr, HCDT v, HCDT a, const char *sch, double
 #pragma omp parallel for
 	for(long i=0;i<v->GetNx();i++)
 	{
-		register mreal v0 = v->v(i);
+		mreal v0 = v->v(i);
 		mgl_cont_gen(gr,v0,a,&xx,&yy,&zz,gr->GetC(ss,v0),text,0);
 	}
 	gr->EndGroup();
@@ -226,7 +228,7 @@ void MGL_EXPORT mgl_cont_z_val(HMGL gr, HCDT v, HCDT a, const char *sch, double
 #pragma omp parallel for
 	for(long i=0;i<v->GetNx();i++)
 	{
-		register mreal v0 = v->v(i);
+		mreal v0 = v->v(i);
 		mgl_cont_gen(gr,v0,a,&xx,&yy,&zz,gr->GetC(ss,v0),text,0);
 	}
 	gr->EndGroup();
@@ -309,7 +311,7 @@ void MGL_EXPORT mgl_contf_x_val(HMGL gr, HCDT v, HCDT a, const char *sch, double
 #pragma omp parallel for
 	for(long i=0;i<v->GetNx()-1;i++)
 	{
-		register mreal v0 = v->v(i);
+		mreal v0 = v->v(i);
 		mgl_contf_gen(gr,v0,v->v(i+1),a,&xx,&yy,&zz,gr->GetC(ss,v0),0);
 	}
 	gr->EndGroup();
@@ -330,7 +332,7 @@ void MGL_EXPORT mgl_contf_y_val(HMGL gr, HCDT v, HCDT a, const char *sch, double
 #pragma omp parallel for
 	for(long i=0;i<v->GetNx()-1;i++)
 	{
-		register mreal v0 = v->v(i);
+		mreal v0 = v->v(i);
 		mgl_contf_gen(gr,v0,v->v(i+1),a,&xx,&yy,&zz,gr->GetC(ss,v0),0);
 	}
 	gr->EndGroup();
@@ -351,7 +353,7 @@ void MGL_EXPORT mgl_contf_z_val(HMGL gr, HCDT v, HCDT a, const char *sch, double
 #pragma omp parallel for
 	for(long i=0;i<v->GetNx()-1;i++)
 	{
-		register mreal v0 = v->v(i);
+		mreal v0 = v->v(i);
 		mgl_contf_gen(gr,v0,v->v(i+1),a,&xx,&yy,&zz,gr->GetC(ss,v0),0);
 	}
 	gr->EndGroup();
