@@ -80,7 +80,7 @@ void MGL_EXPORT mgl_fplot(HMGL gr, const char *eqY, const char *pen, const char
 			}
 		}
 	}
-	mgl_plot_xy(gr,&x,&y,pen,0);
+	delete eq;	mgl_plot_xy(gr,&x,&y,pen,0);
 }
 //-----------------------------------------------------------------------------
 void MGL_EXPORT mgl_fplot_xyz(HMGL gr, const char *eqX, const char *eqY, const char *eqZ, const char *pen, const char *opt)
@@ -209,7 +209,8 @@ void MGL_EXPORT mgl_candle_xyv(HMGL gr, HCDT x, HCDT v1, HCDT v2, HCDT y1, HCDT
 	if(!y1)	{	y1 = new mglData(n);	d1=true;	((mglData *)y1)->Fill(NAN,NAN);	}
 	if(!y2)	{	y2 = new mglData(n);	d2=true;	((mglData *)y2)->Fill(NAN,NAN);	}
 	if(y1->GetNx()!=n || y2->GetNx()!=n)
-	{	gr->SetWarn(mglWarnDim,"Candle");	return;	}
+	{	if(d1)	delete y1;	if(d2)	delete y2;
+		gr->SetWarn(mglWarnDim,"Candle");	return;	}
 	static int cgid=1;	gr->StartGroup("Candle",cgid++);
 	gr->SaveState(opt);	gr->SetPenPal(pen,&pal);	gr->Reserve(8*n);
 	bool sh = mglchr(pen,'!');
@@ -348,7 +349,7 @@ void MGL_EXPORT mgl_plot_xyz(HMGL gr, HCDT x, HCDT y, HCDT z, const char *pen, c
 	gr->SaveState(opt);
 	long m = x->GetNy() > y->GetNy() ? x->GetNy() : y->GetNy();	m = z->GetNy() > m ? z->GetNy() : m;
 	char mk=gr->SetPenPal(pen,&pal);	gr->Reserve(2*n*m);
-	bool sh = mglchr(pen,'!'), orig = !mglchr(pen,'a');
+	bool sh = mglchr(pen,'!'), orig = !mglchr(pen,'a'), appr = mglchr(pen,'~');
 
 	int d = gr->MeshNum>0 ? gr->MeshNum+1 : n, dx = n>d?n/d:1;
 	for(long j=0;j<m;j++)
@@ -359,20 +360,45 @@ void MGL_EXPORT mgl_plot_xyz(HMGL gr, HCDT x, HCDT y, HCDT z, const char *pen, c
 		mglDataR xx(x,mx), yy(y,my), zz(z,mz);
 		const std::vector<mglPointA> &pp = orig ? mgl_pnt_copy(&xx, &yy, &zz, 0) :
 			mgl_pnt_prepare(gr->Min, gr->Max, &xx, &yy, &zz, 0);
-		long n1=-1, n2=-1;
+		size_t num = pp.size();
+		long *nn = new long[num];
+		for(size_t i=0;i<num;i++)
+		{	mreal c = sh ? gr->NextColor(pal,i):gr->CDef;	nn[i] = gr->AddPnt(pp[i].p, c);	}
 		
-		for(size_t i=0;i<pp.size();i++)
+		if(mk)	for(size_t i=0;i<num;i+=dx)
+			if(nn[i]>=0 && pp[i].orig)	gr->mark_plot(nn[i], mk);
+		if(num>1)
 		{
-			mreal c = sh ? gr->NextColor(pal,i):gr->CDef;
-			n2 = n1;	n1 = gr->AddPnt(pp[i].p, c);
-			if(mk && i%dx==0 && n1>=0 && pp[i].orig)	gr->mark_plot(n1,mk);
-			if(n1>=0 && n2>=0)
+			if(nn[0]>=0 && nn[1]>=0)
+				gr->arrow_plot(nn[0],nn[1],gr->Arrow1);
+			if(nn[num-1]>=0 && nn[num-2]>=0)
+				gr->arrow_plot(nn[num-1],nn[num-2],gr->Arrow2);
+		}
+		for(size_t i=0;i+1<num;i++)
+		{
+			if(nn[i]<0 || nn[i+1]<0)	continue;
+			if(!appr)	gr->line_plot(nn[i+1],nn[i]);
+			else
 			{
-				gr->line_plot(n1,n2);
-				if(i==1)	gr->arrow_plot(n2,n1,gr->Arrow1);
+				size_t k=i+2;
+				while(k<num)
+				{
+					const mglPoint p1(gr->GetPntP(i)), p2(gr->GetPntP(k));
+					mreal dy=p2.x-p1.x, dx=p1.y-p2.y, dd=2*(dx*dx+dy*dy);
+					bool ops=false;
+					for(size_t ii=i+1;ii<k;ii++)
+					{
+						const mglPoint p(gr->GetPntP(ii));
+						mreal d = dx*p.x+dy*p.y;
+						if(d*d>dd)	ops = true;
+					}
+					if(ops)	break;
+					k++;
+				}
+				k--;	gr->line_plot(nn[k],nn[i]);	i = k-1;
 			}
 		}
-		if(n1>=0 && n2>=0)	gr->arrow_plot(n1,n2,gr->Arrow2);
+		delete []nn;
 	}
 	gr->EndGroup();
 }
@@ -423,7 +449,7 @@ void MGL_EXPORT mgl_tens_xyz(HMGL gr, HCDT x, HCDT y, HCDT z, HCDT c, const char
 	m = x->GetNy() > y->GetNy() ? x->GetNy() : y->GetNy();	m = z->GetNy() > m ? z->GetNy() : m;
 	char mk=gr->SetPenPal(pen, &pal);	gr->Reserve(2*n*m);
 	long ss=gr->AddTexture(pen);
-	bool orig = !mglchr(pen,'a');
+	bool orig = !mglchr(pen,'a'), appr = mglchr(pen,'~');
 
 	int d = gr->MeshNum>0 ? gr->MeshNum+1 : n, dx = n>d?n/d:1;
 	for(long j=0;j<m;j++)
@@ -434,18 +460,45 @@ void MGL_EXPORT mgl_tens_xyz(HMGL gr, HCDT x, HCDT y, HCDT z, HCDT c, const char
 		mglDataR xx(x,mx), yy(y,my), zz(z,mz), cc(c,mc);
 		const std::vector<mglPointA> &pp = orig ? mgl_pnt_copy(&xx, &yy, &zz, &cc) :
 			mgl_pnt_prepare(gr->Min, gr->Max, &xx, &yy, &zz, &cc);
-		long n1=-1, n2=-1;
-		for(size_t i=0;i<pp.size();i++)
+
+		size_t num = pp.size();
+		long *nn = new long[num];
+		for(size_t i=0;i<num;i++)	nn[i] = gr->AddPnt(pp[i].p, gr->GetC(ss,pp[i].p.c));
+		
+		if(mk)	for(size_t i=0;i<num;i+=dx)
+			if(nn[i]>=0 && pp[i].orig)	gr->mark_plot(nn[i], mk);
+		if(num>1)
 		{
-			n2 = n1;	n1 = gr->AddPnt(pp[i].p, gr->GetC(ss,pp[i].p.c));
-			if(mk && i%dx==0 && n1>=0 && pp[i].orig)	gr->mark_plot(n1,mk);
-			if(n1>=0 && n2>=0)
+			if(nn[0]>=0 && nn[1]>=0)
+				gr->arrow_plot(nn[0],nn[1],gr->Arrow1);
+			if(nn[num-1]>=0 && nn[num-2]>=0)
+				gr->arrow_plot(nn[num-1],nn[num-2],gr->Arrow2);
+		}
+		for(size_t i=0;i+1<num;i++)
+		{
+			if(nn[i]<0 || nn[i+1]<0)	continue;
+			if(!appr)	gr->line_plot(nn[i+1],nn[i]);
+			else
 			{
-				gr->line_plot(n1,n2);
-				if(i==1)	gr->arrow_plot(n2,n1,gr->Arrow1);
+				size_t k=i+2;
+				while(k<num)
+				{
+					const mglPoint p1(gr->GetPntP(i)), p2(gr->GetPntP(k));
+					mreal dy=p2.x-p1.x, dx=p1.y-p2.y, dd=2*(dx*dx+dy*dy);
+					bool ops=false;
+					for(size_t ii=i+1;ii<k;ii++)
+					{
+						const mglPoint p(gr->GetPntP(ii));
+						mreal d = dx*p.x+dy*p.y;
+						if(d*d>dd)	ops = true;
+					}
+					if(ops)	break;
+					k++;
+				}
+				k--;	gr->line_plot(nn[k],nn[i]);	i = k-1;
 			}
 		}
-		if(n1>=0 && n2>=0)	gr->arrow_plot(n1,n2,gr->Arrow2);
+		delete []nn;
 	}
 	gr->EndGroup();
 }
@@ -664,7 +717,8 @@ void MGL_EXPORT mgl_region_3d(HMGL gr, HCDT x1, HCDT y1, HCDT z1, HCDT x2, HCDT
 	long n=y1->GetNx(), m, pal;
 	if(mgl_check_dim1(gr,x1,y1,z1,0,"Region"))	return;
 	if(mgl_check_dim1(gr,x1,x2,y2,z2,"Region"))	return;
-	m = x1->GetNy() > y1->GetNy() ? x1->GetNy() : y1->GetNy();	m = z1->GetNy() > m ? z1->GetNy() : m;
+	m = x1->GetNy() > y1->GetNy() ? x1->GetNy() : y1->GetNy();
+	m = (z1 && z1->GetNy() > m) ? z1->GetNy() : m;
 	bool zhave = z1 && z2;
 	if(x1->GetNy()!=x2->GetNy() || y1->GetNy()!=y2->GetNy())
 	{	gr->SetWarn(mglWarnDim,"Region");	return;	}
@@ -1106,7 +1160,7 @@ void MGL_EXPORT mgl_bars_xy(HMGL gr, HCDT x, HCDT y, const char *pen, const char
 	if(fixed)
 	{
 		long nn=x->GetNy();
-		for(long i=0;i<n-1;i++)	for(long j=0;j<nn;j++)
+		for(long j=0;j<nn;j++)	for(long i=0;i<n-1;i++)
 		{
 			mreal cx = fabs(x->v(i+1,j)-x->v(i,j));
 			if(cx<dx)	dx=cx;
@@ -1202,7 +1256,7 @@ void MGL_EXPORT mgl_barh_yx(HMGL gr, HCDT y, HCDT v, const char *pen, const char
 	if(fixed)
 	{
 		long nn=y->GetNy();
-		for(long i=0;i<n-1;i++)	for(long j=0;j<nn;j++)
+		for(long j=0;j<nn;j++)	for(long i=0;i<n-1;i++)
 		{
 			mreal cx = fabs(y->v(i+1,j)-y->v(i,j));
 			if(cx<dy)	dy=cx;
