@@ -1,6 +1,6 @@
 /***************************************************************************
  * window.cpp is part of Math Graphic Library
- * Copyright (C) 2007-2014 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
+ * Copyright (C) 2007-2016 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU Library General Public License as       *
@@ -39,8 +39,8 @@ void mglCanvasWnd::SetCurFig(int c)
 //-----------------------------------------------------------------------------
 void mglCanvasWnd::ResetFrames()
 {
-	if(GG)	free(GG);	GG = 0;
-	NumFig = CurFig = 0;
+	if(GG)	free(GG);
+	GG = 0;	NumFig = CurFig = 0;
 	mglCanvas::ResetFrames();
 }
 //-----------------------------------------------------------------------------
@@ -86,20 +86,24 @@ void mglCanvasWnd::DelFrame(long i)
 //-----------------------------------------------------------------------------
 void mglCanvasWnd::SetDrawFunc(int (*draw)(mglBase *gr, void *p), void *par, void (*reload)(void *p))
 {
-	ResetFrames();
-	if(get(MGL_CLF_ON_UPD))	DefaultPlotParam();
-	const std::string loc = setlocale(LC_NUMERIC, NULL);	setlocale(LC_NUMERIC, "C");
-	// use frames for quickly redrawing while adding/changing primitives
-	if(mgl_is_frames(this))	NewFrame();
+	if(draw)
+	{
+		ResetFrames();
+		if(get(MGL_CLF_ON_UPD))	DefaultPlotParam();
+		const std::string loc = setlocale(LC_NUMERIC, "C");
+		// use frames for quickly redrawing while adding/changing primitives
+		if(mgl_is_frames(this))	NewFrame();
 
-	int n = draw ? draw(this,par) : 0;
-	if(n<NumFig && n>=0)	NumFig = n;
-	DrawFunc = draw;		FuncPar = par;
-	LoadFunc = reload;
+		int n = draw(this,par);
+		if(n<NumFig && n>=0)	NumFig = n;
+		DrawFunc = draw;		FuncPar = par;
+		LoadFunc = reload;
 
-	if(mgl_is_frames(this))	EndFrame();
-	if(n>=0)	SetCurFig(0);
-	setlocale(LC_NUMERIC, loc.c_str());
+		if(mgl_is_frames(this))	EndFrame();
+		if(n>=0)	SetCurFig(0);
+		setlocale(LC_NUMERIC, loc.c_str());
+	}
+	else	LoadFunc = 0;
 }
 //-----------------------------------------------------------------------------
 const unsigned char *mglCanvasWnd::GetBits()
@@ -117,7 +121,7 @@ void mglCanvasWnd::ReLoad()
 		LoadFunc(FuncPar);
 		// update number of slides
 		ResetFrames();
-		const std::string loc = setlocale(LC_NUMERIC, NULL);	setlocale(LC_NUMERIC, "C");
+		const std::string loc = setlocale(LC_NUMERIC, "C");
 		// use frames for quickly redrawing while adding/changing primitives
 		if(mgl_is_frames(this))	NewFrame();
 
