@@ -40,6 +40,7 @@
 #include "dat_pnl.h"
 #include "info_dlg.h"
 #include "xpm/table.xpm"
+#undef sprintf	// fix libintl bug of defining sprintf
 //-----------------------------------------------------------------------------
 extern mglParse parser;
 void updateDataItems();
@@ -62,7 +63,7 @@ DatPanel::DatPanel(InfoDialog *inf, QWidget *parent) : QWidget(parent)
 	ready = false;	infoDlg = inf;
 	QBoxLayout *v,*h,*m;
 
-	menu = new QMenu(tr("Data"),this);
+	menu = new QMenu(_("Data"),this);
 	v = new QVBoxLayout(this);
 	h = new QHBoxLayout();	v->addLayout(h);	toolTop(h);
 	h = new QHBoxLayout();	v->addLayout(h);
@@ -148,8 +149,8 @@ void DatPanel::setVar(mglDataA *v)
 		QString s = QString::fromWCharArray(v->s.c_str());
 		v->o = this;	v->func = deleteDat;
 		refresh();
-		setWindowTitle(s + tr(" - UDAV variable"));
-		infoDlg->setWindowTitle(s + tr(" - UDAV preview"));
+		setWindowTitle(s + _(" - UDAV variable"));
+		infoDlg->setWindowTitle(s + _(" - UDAV preview"));
 	}
 	else
 	{	tab->setColumnCount(0);	tab->setRowCount(0);	emit nzChanged(nz);	}
@@ -158,7 +159,8 @@ void DatPanel::setVar(mglDataA *v)
 //-----------------------------------------------------------------------------
 void DatPanel::setSlice(int k)
 {
-	if(k>=nz)	k=nz-1;	if(k<0)	k=0;
+	if(k>=nz)	k=nz-1;
+	if(k<0)	k=0;
 	if(k!=kz)
 	{
 		infoDlg->setSlice(k);
@@ -211,8 +213,8 @@ void DatPanel::putValue(int r, int c)
 	if(s=="nan")	f=NAN;
 	else if(s=="inf")	f=INFINITY;
 	else if(s=="-inf")	f=-INFINITY;
-	else	g = mgl_str2dual(s.toLocal8Bit().constData());	//f = s.toDouble();
-	f = real(g);
+	else
+	{	g = mgl_str2dual(s.toLocal8Bit().constData());	f = real(g);	}
 	mglDataC *cc = dynamic_cast<mglDataC*>(var);
 	if(cc)
 	{
@@ -243,20 +245,20 @@ void DatPanel::putValue(int r, int c)
 //-----------------------------------------------------------------------------
 void DatPanel::save()
 {
-	QString fn = QFileDialog::getSaveFileName(this, tr("UDAV - Save/export data"), "",
-				tr("Data files (*.dat)\nHDF5 files (*.h5 *.hdf)\nPNG files (*.png)\nAll files (*.*)"));
+	QString fn = QFileDialog::getSaveFileName(this, _("UDAV - Save/export data"), "",
+				_("Data files (*.dat)\nHDF5 files (*.h5 *.hdf)\nPNG files (*.png)\nAll files (*.*)"));
 	if(fn.isEmpty())	return;
 	QString ext = fn.section(".",-1);
 	if(ext=="png")
 	{
 		bool ok;
-		QString s = QInputDialog::getText(this, tr("UDAV - Export to PNG"), tr("Enter color scheme for picture"), QLineEdit::Normal, MGL_DEF_SCH, &ok);
+		QString s = QInputDialog::getText(this, _("UDAV - Export to PNG"), _("Enter color scheme"), QLineEdit::Normal, MGL_DEF_SCH, &ok);
 		if(ok)	var->Export(fn.toLocal8Bit().constData(), s.toLocal8Bit().constData());
 	}
 	else if(ext=="h5" || ext=="hdf")
 	{
 		bool ok;
-		QString s = QInputDialog::getText(this, tr("UDAV - Save to HDF"), tr("Enter data name"), QLineEdit::Normal, QString::fromWCharArray(var->s.c_str()), &ok);
+		QString s = QInputDialog::getText(this, _("UDAV - Save to HDF"), _("Enter data name"), QLineEdit::Normal, QString::fromWCharArray(var->s.c_str()), &ok);
 		if(ok)	var->SaveHDF(fn.toLocal8Bit().constData(), s.toLocal8Bit().constData());
 	}
 	else 	var->Save(fn.toLocal8Bit().constData());
@@ -265,20 +267,20 @@ void DatPanel::save()
 void DatPanel::load()
 {
 	mglData *d = dynamic_cast<mglData *>(var);	if(!d)	return;
-	QString fn = QFileDialog::getOpenFileName(this, tr("UDAV - Load data"), "",
-				tr("Data files (*.dat)\nHDF5 files (*.h5 *.hdf)\nPNG files (*.png)\nAll files (*.*)"));
+	QString fn = QFileDialog::getOpenFileName(this, _("UDAV - Load data"), "",
+				_("Data files (*.dat)\nHDF5 files (*.h5 *.hdf)\nPNG files (*.png)\nAll files (*.*)"));
 	if(fn.isEmpty())	return;
 	QString ext = fn.section(".",-1);
 	if(ext=="png")
 	{
 		bool ok;
-		QString s = QInputDialog::getText(this, tr("UDAV - Import PNG"), tr("Enter color scheme for picture"), QLineEdit::Normal, MGL_DEF_SCH, &ok);
+		QString s = QInputDialog::getText(this, _("UDAV - Import PNG"), _("Enter color scheme"), QLineEdit::Normal, MGL_DEF_SCH, &ok);
 		if(ok)	d->Import(fn.toLocal8Bit().constData(), s.toLocal8Bit().constData());
 	}
 	else if(ext=="h5" || ext=="hdf")
 	{
 		bool ok;
-		QString s = QInputDialog::getText(this, tr("UDAV - Read from HDF"), tr("Enter data name"), QLineEdit::Normal, QString::fromWCharArray(var->s.c_str()), &ok);
+		QString s = QInputDialog::getText(this, _("UDAV - Read from HDF"), _("Enter data name"), QLineEdit::Normal, QString::fromWCharArray(var->s.c_str()), &ok);
 		if(ok)	d->ReadHDF(fn.toLocal8Bit().constData(), s.toLocal8Bit().constData());
 	}
 	else 	d->Read(fn.toLocal8Bit().constData());
@@ -288,11 +290,10 @@ void DatPanel::load()
 void DatPanel::copy()
 {
 	QTableWidgetSelectionRange ts = tab->selectedRanges().first();
-	register long i,j;
 	QString res, s;
-	for(j=ts.topRow();j<=ts.bottomRow();j++)
+	for(long j=ts.topRow();j<=ts.bottomRow();j++)
 	{
-		for(i=ts.leftColumn();i<=ts.rightColumn();i++)
+		for(long i=ts.leftColumn();i<=ts.rightColumn();i++)
 		{
 			res = res + tab->item(j,i)->text();
 			if(i<ts.rightColumn())	res = res + "\t";
@@ -329,14 +330,13 @@ void DatPanel::plot()	// TODO: plot dialog
 void DatPanel::list()	// TODO: in which script insert ???
 {
 /*	if(nx*ny+ny > 1020)
-	{	QMessageBox::warning(this, tr("UDAV - To list conversion"), tr("Too many numbers (>1000) on slice"), QMessageBox::Ok, 0, 0);	return;	}
+	{	QMessageBox::warning(this, _("UDAV - To list conversion"), _("Too many numbers (>1000) on slice"), QMessageBox::Ok, 0, 0);	return;	}
 	if(nz > 1)
-		QMessageBox::information(this, tr("UDAV - To list conversion"), tr("Only current slice will be inserted"), QMessageBox::Ok, 0, 0);
+		QMessageBox::information(this, _("UDAV - To list conversion"), _("Only current slice will be inserted"), QMessageBox::Ok, 0, 0);
 	QString res = "list\t", s;
-	register long i,j;
-	for(j=0;j<ny;j++)
+	for(long j=0;j<ny;j++)
 	{
-		for(i=0;i<nx;i++)
+	for(long i=0;i<nx;i++)
 		{
 			s.sprintf("%g\t",d->a[i+nx*(j+kz*ny)]);
 			res += s;
@@ -348,7 +348,7 @@ void DatPanel::list()	// TODO: in which script insert ???
 void DatPanel::inrange()
 {
 	QString v1("-1"), v2("1"), dir("x");
-	if(sizesDialog(tr("UDAV - Fill data"), tr("Enter range for data and direction of filling"), tr("From"), tr("To"), tr("Direction"), v1, v2, dir))
+	if(sizesDialog(_("UDAV - Fill data"), _("Enter range for data and direction of filling"), _("From"), _("To"), _("Direction"), v1, v2, dir))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Fill(v1.toDouble(), v2.toDouble(), dir[0].toLatin1());
@@ -363,7 +363,7 @@ void DatPanel::inrange()
 void DatPanel::norm()
 {
 	QString v1("0"), v2("1"), how;
-	if(sizesDialog(tr("UDAV - Normalize data"), tr("Enter range for final data"), tr("From"), tr("To"), tr("Symmetrical?"), v1, v2, how))
+	if(sizesDialog(_("UDAV - Normalize data"), _("Enter range for final data"), _("From"), _("To"), _("Symmetrical?"), v1, v2, how))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Norm(v1.toDouble(), v2.toDouble(), (how=="on" || how.contains('s')));
@@ -374,7 +374,7 @@ void DatPanel::norm()
 void DatPanel::normsl()
 {
 	QString v1("0"), v2("1"), dir("z");
-	if(sizesDialog(tr("UDAV - Normalize by slice"), tr("Enter range for final data"), tr("From"), tr("To"), tr("Direction"), v1, v2, dir))
+	if(sizesDialog(_("UDAV - Normalize by slice"), _("Enter range for final data"), _("From"), _("To"), _("Direction"), v1, v2, dir))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->NormSl(v1.toDouble(), v2.toDouble(), dir[0].toLatin1());
@@ -385,7 +385,7 @@ void DatPanel::normsl()
 void DatPanel::create()
 {
 	QString mx, my("1"), mz("1");
-	if(sizesDialog(tr("UDAV - Clear data"), tr("Enter new data sizes"), tr("X-size"), tr("Y-size"), tr("Z-size"), mx, my, mz))
+	if(sizesDialog(_("UDAV - Clear data"), _("Enter new data sizes"), _("X-size"), _("Y-size"), _("Z-size"), mx, my, mz))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Create(mx.toInt(), my.toInt(), mz.toInt());
@@ -399,7 +399,7 @@ void DatPanel::reSize()
 {
 	QString mx, my, mz;
 	mx.sprintf("%d",nx);	my.sprintf("%d",ny);	mz.sprintf("%d",nz);
-	if(sizesDialog(tr("UDAV - Resize data"), tr("Enter new data sizes"), tr("X-size"), tr("Y-size"), tr("Z-size"), mx, my, mz))
+	if(sizesDialog(_("UDAV - Resize data"), _("Enter new data sizes"), _("X-size"), _("Y-size"), _("Z-size"), mx, my, mz))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Set(d->Resize(mx.toInt(), my.toInt(), mz.toInt()));
@@ -410,7 +410,7 @@ void DatPanel::reSize()
 void DatPanel::squize()
 {
 	QString mx("1"), my("1"), mz("1");
-	if(sizesDialog(tr("UDAV - Squeeze data"), tr("Enter step of saved points. For example, '1' save all, '2' save each 2nd point, '3' save each 3d and so on."), tr("X-direction"), tr("Y-direction"), tr("Z-direction"), mx, my, mz))
+	if(sizesDialog(_("UDAV - Squeeze data"), _("Enter step of saved points. For example, '1' save all, '2' save each 2nd point, '3' save each 3d and so on."), _("X-direction"), _("Y-direction"), _("Z-direction"), mx, my, mz))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Squeeze(mx.toInt(), my.toInt(), mz.toInt());
@@ -421,7 +421,7 @@ void DatPanel::squize()
 void DatPanel::crop()
 {
 	QString n1("1"), n2("1"), dir;
-	if(sizesDialog(tr("UDAV - Crop data"), tr("Enter range of saved date."), tr("From"), tr("To"), tr("Direction"), n1, n2, dir))
+	if(sizesDialog(_("UDAV - Crop data"), _("Enter range of saved date."), _("From"), _("To"), _("Direction"), n1, n2, dir))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Squeeze(n1.toInt(), n2.toInt(), dir[0].toLatin1());
@@ -433,7 +433,7 @@ void DatPanel::rearrange()
 {
 	QString mx, my, mz;
 	mx.sprintf("%d",nx);	my.sprintf("%d",ny);	mz.sprintf("%d",nz);
-	if(sizesDialog(tr("UDAV - Rearrange data"), tr("Enter new data sizes"), tr("X-size"), tr("Y-size"), tr("Z-size"), mx, my, mz))
+	if(sizesDialog(_("UDAV - Rearrange data"), _("Enter new data sizes"), _("X-size"), _("Y-size"), _("Z-size"), mx, my, mz))
 	{
 		mglData *d = dynamic_cast<mglData *>(var);
 		if(d)	d->Rearrange(mx.toInt(), my.toInt(), mz.toInt());
@@ -447,19 +447,19 @@ void DatPanel::hist()
 	QLineEdit *id, *v1, *v2;
 	QSpinBox *nm;
 	QPushButton *b;
-	QDialog *d = new QDialog(this);	d->setWindowTitle(tr("UDAV - Make histogram"));
+	QDialog *d = new QDialog(this);	d->setWindowTitle(_("UDAV - Make histogram"));
 	QGridLayout *g = new QGridLayout(d);
-	l = new QLabel(tr("From"), d);	g->addWidget(l,0,0);
-	l = new QLabel(tr("To"), d);	g->addWidget(l,0,1);
+	l = new QLabel(_("From"), d);	g->addWidget(l,0,0);
+	l = new QLabel(_("To"), d);	g->addWidget(l,0,1);
 	v1 = new QLineEdit(d);	g->addWidget(v1,1,0);
 	v2 = new QLineEdit(d);	g->addWidget(v2,1,1);
-	l = new QLabel(tr("Number of points"), d);	g->addWidget(l,2,0);
-	l = new QLabel(tr("Put in variable"), d);	g->addWidget(l,2,1);
+	l = new QLabel(_("Number of points"), d);	g->addWidget(l,2,0);
+	l = new QLabel(_("Put in variable"), d);	g->addWidget(l,2,1);
 	nm = new QSpinBox(d);	nm->setRange(2,8192);	g->addWidget(nm,3,0);
 	id = new QLineEdit(d);	nm->setSingleStep(10);	g->addWidget(id,3,1);
-	b = new QPushButton(tr("Cancel"), d);	g->addWidget(b,4,0);
+	b = new QPushButton(_("Cancel"), d);	g->addWidget(b,4,0);
 	connect(b, SIGNAL(clicked()), d, SLOT(reject()));
-	b = new QPushButton(tr("OK"), d);		g->addWidget(b,4,1);
+	b = new QPushButton(_("OK"), d);		g->addWidget(b,4,1);
 	connect(b, SIGNAL(clicked()), d, SLOT(accept()));	b->setDefault(true);
 	// now execute dialog and get values
 	bool res = d->exec();
@@ -482,7 +482,7 @@ void DatPanel::prev()	{	setSlice(kz-1);	}
 void DatPanel::gosl()
 {
 	bool ok;
-	QString s = QInputDialog::getText(this, tr("UDAV - Go to slice"), tr("Enter slice id:"), QLineEdit::Normal, "0", &ok);
+	QString s = QInputDialog::getText(this, _("UDAV - Go to slice"), _("Enter slice id:"), QLineEdit::Normal, "0", &ok);
 	if(ok)	setSlice(s.toInt());
 }
 //-----------------------------------------------------------------------------
@@ -497,7 +497,7 @@ bool DatPanel::sizesDialog(const QString &cap, const QString &lab, const QString
 	d->setWindowTitle(cap);
 	QVBoxLayout *v = new QVBoxLayout(d);
 	l = new QLabel(lab, d);	v->addWidget(l);
-	l = new QLabel(tr("NOTE: All fields must be filled!"), d);	v->addWidget(l);
+	l = new QLabel(_("NOTE: All fields must be filled!"), d);	v->addWidget(l);
 	QGridLayout *g = new QGridLayout();	v->addLayout(g);
 	l = new QLabel(desc1, d);		g->addWidget(l, 0, 0);
 	l = new QLabel(desc2, d);		g->addWidget(l, 0, 1);
@@ -507,9 +507,9 @@ bool DatPanel::sizesDialog(const QString &cap, const QString &lab, const QString
 	f3 = new QLineEdit(val3, d);	g->addWidget(f3, 1, 2);
 	QHBoxLayout *h = new QHBoxLayout();	v->addLayout(h);
 	h->addStretch(1);
-	b = new QPushButton(tr("Cancel"), d);	h->addWidget(b);
+	b = new QPushButton(_("Cancel"), d);	h->addWidget(b);
 	connect(b, SIGNAL(clicked()), d, SLOT(reject()));
-	b = new QPushButton(tr("OK"), d);		h->addWidget(b);
+	b = new QPushButton(_("OK"), d);		h->addWidget(b);
 	connect(b, SIGNAL(clicked()), d, SLOT(accept()));
 	b->setDefault(true);
 	// now execute dialog and get values
@@ -533,25 +533,25 @@ void DatPanel::newdat()
 	QLineEdit *f1, *f2;
 	QPushButton *b;
 	QDialog *d = new QDialog(this);
-	d->setWindowTitle(tr("UDAV - make new data"));
+	d->setWindowTitle(_("UDAV - make new data"));
 	QVBoxLayout *v = new QVBoxLayout(d);
 	QComboBox *c = new QComboBox(d);	v->addWidget(c);
-	c->addItem(tr("Sum along direction(s)"));
-	c->addItem(tr("Min along direction(s)"));
-	c->addItem(tr("Max along direction(s)"));
-	c->addItem(tr("Momentum along 'x' for function"));
-	c->addItem(tr("Momentum along 'y' for function"));
-	c->addItem(tr("Momentum along 'z' for function"));
+	c->addItem(_("Sum along direction(s)"));
+	c->addItem(_("Min along direction(s)"));
+	c->addItem(_("Max along direction(s)"));
+	c->addItem(_("Momentum along 'x' for function"));
+	c->addItem(_("Momentum along 'y' for function"));
+	c->addItem(_("Momentum along 'z' for function"));
 	c->setCurrentIndex(0);
 
 	f1 = new QLineEdit("z",d);	v->addWidget(f1);
-	QCheckBox *cb = new QCheckBox(tr("Put into this data array"), d);	v->addWidget(cb);
-	l = new QLabel(tr("or enter name for new variable"), d);	v->addWidget(l);
+	QCheckBox *cb = new QCheckBox(_("Put into this data array"), d);	v->addWidget(cb);
+	l = new QLabel(_("or enter name for new variable"), d);	v->addWidget(l);
 	f2 = new QLineEdit(d);		v->addWidget(f2);
 	QHBoxLayout *h = new QHBoxLayout();	v->addLayout(h);	h->addStretch(1);
-	b = new QPushButton(tr("Cancel"), d);	h->addWidget(b);
+	b = new QPushButton(_("Cancel"), d);	h->addWidget(b);
 	connect(b, SIGNAL(clicked()), d, SLOT(reject()));
-	b = new QPushButton(tr("OK"), d);		h->addWidget(b);
+	b = new QPushButton(_("OK"), d);		h->addWidget(b);
 	connect(b, SIGNAL(clicked()), d, SLOT(accept()));
 	b->setDefault(true);
 	// now execute dialog and get values
@@ -563,14 +563,14 @@ void DatPanel::newdat()
 	{
 		if(k<0)
 		{
-			QMessageBox::warning(d, tr("UDAV - make new data"),
-				tr("No action is selected. Do nothing."));
+			QMessageBox::warning(d, _("UDAV - make new data"),
+				_("No action is selected. Do nothing."));
 			return;
 		}
 		if(val.isEmpty())
 		{
-			QMessageBox::warning(d, tr("UDAV - make new data"),
-				tr("No direction/formula is entered. Do nothing."));
+			QMessageBox::warning(d, _("UDAV - make new data"),
+				_("No direction/formula is entered. Do nothing."));
 			return;
 		}
 		if(cb->isChecked())	k += 6;
@@ -605,30 +605,30 @@ void DatPanel::oper()
 	QLineEdit *f1;
 	QPushButton *b;
 	QDialog *d = new QDialog(this);
-	d->setWindowTitle(tr("UDAV - change data"));
+	d->setWindowTitle(_("UDAV - change data"));
 	QVBoxLayout *v = new QVBoxLayout(d);
 	QComboBox *c = new QComboBox(d);	v->addWidget(c);
-	c->addItem(tr("Fill data by formula"));
-	c->addItem(tr("Transpose data with new dimensions"));
-	c->addItem(tr("Smooth data along direction(s)"));
-	c->addItem(tr("Summarize data along direction(s)"));
-	c->addItem(tr("Integrate data along direction(s)"));
-	c->addItem(tr("Differentiate data along direction(s)"));
-	c->addItem(tr("Laplace transform along direction(s)"));
-	c->addItem(tr("Swap data along direction(s)"));
-	c->addItem(tr("Mirror data along direction(s)"));
-	c->addItem(tr("Sin-Fourier transform along direction(s)"));
-	c->addItem(tr("Cos-Fourier transform along direction(s)"));
-	c->addItem(tr("Hankel transform along direction(s)"));
-	c->addItem(tr("Sew data along direction(s)"));
-	c->addItem(tr("Find envelope along direction(s)"));
+	c->addItem(_("Fill data by formula"));
+	c->addItem(_("Transpose data with new dimensions"));
+	c->addItem(_("Smooth data along direction(s)"));
+	c->addItem(_("Summarize data along direction(s)"));
+	c->addItem(_("Integrate data along direction(s)"));
+	c->addItem(_("Differentiate data along direction(s)"));
+	c->addItem(_("Laplace transform along direction(s)"));
+	c->addItem(_("Swap data along direction(s)"));
+	c->addItem(_("Mirror data along direction(s)"));
+	c->addItem(_("Sin-Fourier transform along direction(s)"));
+	c->addItem(_("Cos-Fourier transform along direction(s)"));
+	c->addItem(_("Hankel transform along direction(s)"));
+	c->addItem(_("Sew data along direction(s)"));
+	c->addItem(_("Find envelope along direction(s)"));
 	c->setCurrentIndex(0);
 
 	f1 = new QLineEdit("z",d);	v->addWidget(f1);
 	QHBoxLayout *h = new QHBoxLayout();	v->addLayout(h);	h->addStretch(1);
-	b = new QPushButton(tr("Cancel"), d);	h->addWidget(b);
+	b = new QPushButton(_("Cancel"), d);	h->addWidget(b);
 	connect(b, SIGNAL(clicked()), d, SLOT(reject()));
-	b = new QPushButton(tr("OK"), d);		h->addWidget(b);
+	b = new QPushButton(_("OK"), d);		h->addWidget(b);
 	connect(b, SIGNAL(clicked()), d, SLOT(accept()));
 	b->setDefault(true);
 	// now execute dialog and get values
@@ -640,8 +640,8 @@ void DatPanel::oper()
 	{
 		if(k<0)
 		{
-			QMessageBox::warning(d, tr("UDAV - make new data"),
-				tr("No action is selected. Do nothing."));
+			QMessageBox::warning(d, _("UDAV - make new data"),
+				_("No action is selected. Do nothing."));
 			return;
 		}
 		switch(k)
@@ -678,80 +678,80 @@ void DatPanel::toolTop(QBoxLayout *l)
 	QToolButton *bb;
 
 	// file menu
-	o = menu->addMenu(tr("File"));
-	a = new QAction(QPixmap(":/png/document-open.png"), tr("Load data"), this);
+	o = menu->addMenu(_("File"));
+	a = new QAction(QPixmap(":/png/document-open.png"), _("Load data"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(load()));
-	a->setToolTip(tr("Load data from file. Data will be deleted only\nat exit but UDAV will not ask to save it (Ctrl+Shift+O)."));
+	a->setToolTip(_("Load data from file. Data will be deleted only\nat exit but UDAV will not ask to save it (Ctrl+Shift+O)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_O);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(":/png/document-save.png"), tr("Save data"), this);
+	a = new QAction(QPixmap(":/png/document-save.png"), _("Save data"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(save()));
-	a->setToolTip(tr("Save data to a file (Ctrl+Shift+S)."));
+	a->setToolTip(_("Save data to a file (Ctrl+Shift+S)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_S);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
 //	o->addSeparator();	bb->addSeparator();
-//	a = new QAction(QPixmap(insert_xpm), tr("Insert as list"), this);
+//	a = new QAction(QPixmap(insert_xpm), _("Insert as list"), this);
 //	connect(a, SIGNAL(triggered()), this, SLOT(list()));
 //	o->addAction(a);
 //	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
 
-	a = new QAction(QPixmap(":/png/office-chart-line.png"), tr("Plot data"), this);
+	a = new QAction(QPixmap(":/png/office-chart-line.png"), _("Plot data"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(plot()));
-	a->setToolTip(tr("Plot data in new script window. You may select the kind\nof plot, its style and so on."));
+	a->setToolTip(_("Plot data in new script window. You may select the kind\nof plot, its style and so on."));
 	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(":/png/edit-copy.png"), tr("Copy data"), this);
+	a = new QAction(QPixmap(":/png/edit-copy.png"), _("Copy data"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(copy()));
-	a->setToolTip(tr("Copy range of numbers to clipboard (Ctrl+Shift+C)."));
+	a->setToolTip(_("Copy range of numbers to clipboard (Ctrl+Shift+C)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_C);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(":/png/edit-paste.png"), tr("Paste data"), this);
+	a = new QAction(QPixmap(":/png/edit-paste.png"), _("Paste data"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(copy()));
-	a->setToolTip(tr("Paste range of numbers from clipboard (Ctrl+Shift+P)."));
+	a->setToolTip(_("Paste range of numbers from clipboard (Ctrl+Shift+P)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_V);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
 	// navigation menu
-	o = menu->addMenu(tr("Navigate"));
-	a = new QAction(QPixmap(":/png/go-first.png"), tr("First slice"), this);
+	o = menu->addMenu(_("Navigation"));
+	a = new QAction(QPixmap(":/png/go-first.png"), _("First slice"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(first()));
-	a->setToolTip(tr("Go to the first data slice for 3D data."));
-	o->addAction(a);
+	a->setToolTip(_("Go to first slice for 3D data (Ctrl-F1)."));
+	a->setShortcut(Qt::CTRL+Qt::Key_F1);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(":/png/go-previous.png"), tr("Prev. slice"), this);
+	a = new QAction(QPixmap(":/png/go-previous.png"), _("Prev slice"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(prev()));
-	a->setToolTip(tr("Go to the previous data slice for 3D data."));
+	a->setToolTip(_("Go to the previous slice for 3D data."));
 	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
 	sb = new QSpinBox(this);
 	l->addWidget(sb);	sb->setRange(0,0);
-	sb->setToolTip(tr("Go to the specified data slice for 3D data."));
+	sb->setToolTip(_("Go to the specified slice for 3D data."));
 	connect(sb, SIGNAL(valueChanged(int)), this, SLOT(setSlice(int)));
 	connect(this, SIGNAL(sliceChanged(int)), sb, SLOT(setValue(int)));
 	connect(this, SIGNAL(nzChanged(int)), this, SLOT(setNz(int)));
 
-	a = new QAction(tr("Go to slice"), this);
+	a = new QAction(_("Go to slice"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(gosl()));
-	a->setToolTip(tr("Go to the specified data slice for 3D data."));
+	a->setToolTip(_("Go to the specified slice for 3D data."));
 	o->addAction(a);
 
-	a = new QAction(QPixmap(":/png/go-next.png"), tr("Next slice"), this);
+	a = new QAction(QPixmap(":/png/go-next.png"), _("Next slice"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(next()));
-	a->setToolTip(tr("Go to the next data slice for 3D data."));
+	a->setToolTip(_("Go to the next slice for 3D data."));
 	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(":/png/go-last.png"), tr("Last slice"), this);
+	a = new QAction(QPixmap(":/png/go-last.png"), _("Last slice"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(last()));
-	a->setToolTip(tr("Go to the last data slice for 3D data."));
-	o->addAction(a);
+	a->setToolTip(_("Go to last slice for 3D data (Ctrl-F4)."));
+	a->setShortcut(Qt::CTRL+Qt::Key_F4);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 }
 //-----------------------------------------------------------------------------
@@ -762,77 +762,77 @@ void DatPanel::toolLeft(QBoxLayout *l)
 	QToolButton *bb;
 
 	// size menu
-	o = menu->addMenu(tr("Sizes"));
-	a = new QAction(QPixmap(":/png/document-new.png"), tr("Create new"), this);
+	o = menu->addMenu(_("Sizes"));
+	a = new QAction(QPixmap(":/png/document-new.png"), _("Create new"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(create()));
-	a->setToolTip(tr("Recreate the data with new sizes and fill it by zeros (Ctrl+Shift+N)."));
+	a->setToolTip(_("Recreate the data with new sizes and fill it by zeros (Ctrl+Shift+N)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_N);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(size_xpm), tr("Resize"), this);
+	a = new QAction(QPixmap(size_xpm), _("Resize"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(reSize()));
-	a->setToolTip(tr("Resize (interpolate) the data to specified sizes (Ctrl+Shift+R)."));
+	a->setToolTip(_("Resize (interpolate) the data to specified sizes (Ctrl+Shift+R)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_R);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(squize_xpm), tr("Squeeze"), this);
+	a = new QAction(QPixmap(squize_xpm), _("Squeeze"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(squize()));
-	a->setToolTip(tr("Keep only each n-th element of the data array."));
+	a->setToolTip(_("Keep only each n-th element of the data array."));
 	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(crop_xpm), tr("Cro&p"), this);
+	a = new QAction(QPixmap(crop_xpm), _("Crop"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(crop()));
-	a->setToolTip(tr("Crop the data edges. Useful to cut off the zero-filled area."));
+	a->setToolTip(_("Crop the data edges. Useful to cut off the zero-filled area."));
 	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(oper_of_xpm), tr("Transform"), this);
+	a = new QAction(QPixmap(oper_of_xpm), _("Transform"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(newdat()));
-	a->setToolTip(tr("Transform data along dimension(s) (Ctrl+Shift+T)."));
+	a->setToolTip(_("Transform data along dimension(s) (Ctrl+Shift+T)."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_T);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(oper_dir_xpm), tr("Make new (Ctrl+Shift+M)"), this);
+	a = new QAction(QPixmap(oper_dir_xpm), _("Make new (Ctrl+Shift+M)"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(oper()));
-	a->setToolTip(tr("Make another data."));
+	a->setToolTip(_("Make another data."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_M);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-	a = new QAction(QPixmap(hist_xpm), tr("Histogram (Ctrl+Shift+H)"), this);
+	a = new QAction(QPixmap(hist_xpm), _("Histogram (Ctrl+Shift+H)"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(hist()));
-	a->setToolTip(tr("Find histogram of data."));
+	a->setToolTip(_("Find histogram of data."));
 	a->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_H);	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 
-/*	a = new QAction(QPixmap(":/png/view-refresh.png"), tr("Refresh"), this);
+/*	a = new QAction(QPixmap(":/png/view-refresh.png"), _("Refresh"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(refresh()));
-	a->setToolTip(tr("Refresh data values."));
+	a->setToolTip(_("Refresh data values."));
 	o->addAction(a);
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);*/
 
-/*	a = new QAction(tr("Rearrange"), this);	// TODO: move in generalized dialog
+/*	a = new QAction(_("Rearrange"), this);	// TODO: move in generalized dialog
 	connect(a, SIGNAL(triggered()), this, SLOT(rearrange()));
-	a->setToolTip(tr("Rearrange data sizes without changing data values."));
+	a->setToolTip(_("Rearrange data sizes without changing data values."));
 	o->addAction(a);
-	a = new QAction(tr("Fill in range"), this);
+	a = new QAction(_("Fill in range"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(inrange()));
-	a->setToolTip(tr("Fill data equidistantly from one value to another."));
+	a->setToolTip(_("Fill data equidistantly from one value to another."));
 	o->addAction(a);
-	a = new QAction(tr("Normalize"), this);
+	a = new QAction(_("Normalize"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(norm()));
-	a->setToolTip(tr("Normalize data so that its minimal\nand maximal values be in specified range."));
+	a->setToolTip(_("Normalize data so that its minimal\nand maximal values be in specified range."));
 	o->addAction(a);
-	a = new QAction(tr("Norm. slices"), this);
+	a = new QAction(_("Norm. slices"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(normsl()));
-	a->setToolTip(tr("Normalize each data slice perpendicular to some direction\nso that its minimal and maximal values be in specified range."));
+	a->setToolTip(_("Normalize each data slice perpendicular to some direction\nso that its minimal and maximal values be in specified range."));
 	o->addAction(a);*/
 
 	l->addStretch(1);
 
-	a = new QAction(QPixmap(":/png/tab-close.png"), tr("Close tab"), this);
+	a = new QAction(QPixmap(":/png/tab-close.png"), _("Close tab"), this);
 	connect(a, SIGNAL(triggered()), this, SLOT(close()));
-	a->setToolTip(tr("Close this data tab."));
+	a->setToolTip(_("Close this data tab."));
 	bb = new QToolButton(this);	l->addWidget(bb);	bb->setDefaultAction(a);
 }
 //-----------------------------------------------------------------------------
