@@ -26,6 +26,7 @@
 //-----------------------------------------------------------------------------
 #include "mem_pnl.h"
 #include "info_dlg.h"
+#undef sprintf	// fix libintl bug of defining sprintf
 //-----------------------------------------------------------------------------
 #include "xpm/table.xpm"
 #include "xpm/preview.xpm"
@@ -54,22 +55,22 @@ MemPanel::MemPanel(QWidget *parent) : QWidget(parent)
 
 	QToolBar *t = new QToolBar(this);	t->setMovable(false);
 	QVBoxLayout *v = new QVBoxLayout(this);	v->addWidget(t);
-	t->addAction(QPixmap(":/png/document-new.png"), tr("Create new data array"), this, SLOT(newTable()));
-	t->addAction(QPixmap(table_xpm), tr("Edit selected data array"), this, SLOT(editData()));
-	t->addAction(QPixmap(":/png/edit-delete.png"), tr("Delete selected data array"), this, SLOT(delData()));
-	t->addAction(QPixmap(preview_xpm), tr("Properties of selected data array"), this, SLOT(infoData()));
-	t->addAction(QPixmap(":/png/view-refresh.png"), tr("Update list of data arrays"), this, SLOT(refresh()));
+	t->addAction(QPixmap(":/png/document-new.png"), _("Create new data array"), this, SLOT(newTable()));
+	t->addAction(QPixmap(table_xpm), _("Edit selected data array"), this, SLOT(editData()));
+	t->addAction(QPixmap(":/png/edit-delete.png"), _("Delete selected data array"), this, SLOT(delData()));
+	t->addAction(QPixmap(preview_xpm), _("Properties of selected data array"), this, SLOT(infoData()));
+	t->addAction(QPixmap(":/png/view-refresh.png"), _("Update list of data arrays"), this, SLOT(refresh()));
 	t->addSeparator();
-	t->addAction(QPixmap(":/png/edit-clear.png"), tr("Delete ALL data arrays"), this, SLOT(delAllData()));
+	t->addAction(QPixmap(":/png/edit-clear.png"), _("Delete ALL data arrays"), this, SLOT(delAllData()));
 
 	colSort = 0;
 	tab = new QTableWidget(this);	tab->setColumnCount(3);	v->addWidget(tab);
-	QStringList sl;	sl<<tr("Name")<<tr("Sizes")<<tr("Memory");
+	QStringList sl;	sl<<_("Name")<<_("Sizes")<<_("Memory");
 	tab->setHorizontalHeaderLabels(sl);
 	connect(tab, SIGNAL(cellClicked(int,int)), this, SLOT(tableClicked(int,int)));
 	connect(tab, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(tableDClicked(int,int)));
 
-	setWindowTitle(tr("Memory"));
+	setWindowTitle(_("Memory"));
 }
 //-----------------------------------------------------------------------------
 void MemPanel::tableClicked(int, int col)
@@ -80,8 +81,8 @@ void MemPanel::tableDClicked(int row, int)	{	editData(row);	}
 void MemPanel::newTable()
 {
 	bool ok;
-	QString name = QInputDialog::getText(this, tr("UDAV - New variable"),
-				tr("Enter name for new variable"), QLineEdit::Normal, "", &ok);
+	QString name = QInputDialog::getText(this, _("UDAV - New variable"),
+				_("Enter name for new variable"), QLineEdit::Normal, "", &ok);
 	if(!ok || name.isEmpty())	return;
 	mglDataA *v = parser.AddVar(name.toLocal8Bit().constData());
 	QWidget *t;
@@ -110,15 +111,15 @@ void MemPanel::delData()
 	int	n = tab->currentRow();
 	if(n<0)	n = 0;
 	mglDataA *v = parser.FindVar(tab->item(n,0)->text().toLocal8Bit().constData());
-	if(!v && v->o)	((QWidget *)v->o)->close();
+	if(v && v->o)	((QWidget *)v->o)->close();
 	parser.DeleteVar(tab->item(n,0)->text().toLocal8Bit().constData());
 	refresh();
 }
 //-----------------------------------------------------------------------------
 void MemPanel::delAllData()
 {
-	if(QMessageBox::information(this, tr("UDAV - delete all data"),
-			tr("Do you want to delete all data?"), QMessageBox::No,
+	if(QMessageBox::information(this, _("UDAV - delete all data"),
+			_("Do you want to delete all data?"), QMessageBox::No,
 			QMessageBox::Yes)!=QMessageBox::Yes)	return;
 	parser.DeleteAll();	refresh();
 }
@@ -132,7 +133,7 @@ void MemPanel::infoData()
 	if(!v)	return;
 	infoDlg->setVar(v);
 	QString s = QString::fromWCharArray(v->s.c_str());
-	infoDlg->setWindowTitle(s + tr(" - UDAV preview"));
+	infoDlg->setWindowTitle(s + _(" - UDAV preview"));
 	infoDlg->refresh();
 	infoDlg->show();
 }
@@ -164,7 +165,7 @@ void MemPanel::refresh()
 		else if(dynamic_cast<mglDataF*>(v))	sv = sizeof(mglDataF);
 		else if(dynamic_cast<mglDataR*>(v))	sv = sizeof(mglDataR);
 		else if(dynamic_cast<mglDataT*>(v))	sv = sizeof(mglDataT);
-		if(sv==0)	s = tr("unknown");
+		if(sv==0)	s = _("unknown");
 #if MGL_SIZEOF_LONG>4
 //		else if((sv>>80L)>0)	s.sprintf("%ld Yb",sv>>80L);
 //		else if((sv>>70L)>0)	s.sprintf("%ld Zb",sv>>70L);
