@@ -47,37 +47,37 @@ NewCmdDialog::NewCmdDialog(QWidget *p) : QDialog(p,Qt::WindowStaysOnTopHint)
 	stlDialog = new StyleDialog(this);
 	datDialog = new DataDialog(this);
 	type = new QComboBox(this);		o->addWidget(type);
-	type->setToolTip(tr("Groups of MGL commands"));
+	type->setToolTip(_("Groups of MGL commands"));
 	fillList();
 	name = new QComboBox(this);		o->addWidget(name);
-	name->setToolTip(tr("MGL commands for selected group"));
+	name->setToolTip(_("MGL commands for selected group"));
 	name->addItems(argn[0]);
 	info = new QLabel(this);		o->addWidget(info);
-	info->setToolTip(tr("Short description of selected command"));
+	info->setToolTip(_("Short description of selected command"));
 	kind= new QComboBox(this);		o->addWidget(kind);	kind->addItem("");
-	kind->setToolTip(tr("Kind of command argument order. The notation is:\n"
+	kind->setToolTip(_("Kind of command argument order. The notation is:\n"
 						" * Capital arguments are data (like, Ydat);\n"
 						" * Argument in '' are strings (like, 'fmt');\n"
 						" * Other arguments are numbers (like, zval);\n"
 						" * Arguments in [] are optional arguments."));
 	args = new QTableWidget(this);	o->addWidget(args);
-	args->setToolTip(tr("Command arguments. Bold ones are required arguments.\n"
+	args->setToolTip(_("Command arguments. Bold ones are required arguments.\n"
 						"Other are optional arguments but its order is required.\n"
 						"You can use '' for default format. See help at right\nfor default values."));
-	QStringList sl;	sl<<tr("Argument")<<tr("Value");
+	QStringList sl;	sl<<_("Argument")<<_("Value");
 	args->setHorizontalHeaderLabels(sl);
 	connect(args,SIGNAL(cellDoubleClicked(int,int)), this, SLOT(insertData()));
 
 	a = new QHBoxLayout;	o->addLayout(a);
-	b = new QPushButton(tr("Options"),this);	a->addWidget(b);
-	b->setToolTip(tr("Here you can specify command options.\nOptions are used for additional plot tunning."));
+	b = new QPushButton(_("Options"),this);	a->addWidget(b);
+	b->setToolTip(_("Here you can specify command options.\nOptions are used for additional plot tunning."));
 	connect(b, SIGNAL(clicked()),this,SLOT(insertOpt()));
 	opt = new QLineEdit(this);	a->addWidget(opt);
 
 	a = new QHBoxLayout;	o->addLayout(a);
-	b = new QPushButton(tr("Cancel"),this);	a->addWidget(b);
+	b = new QPushButton(_("Cancel"),this);	a->addWidget(b);
 	connect(b, SIGNAL(clicked()), this, SLOT(reject()));
-	b = new QPushButton(tr("OK"),this);	a->addWidget(b);
+	b = new QPushButton(_("OK"),this);	a->addWidget(b);
 	connect(b, SIGNAL(clicked()), this, SLOT(finish()));
 
 	o = new QVBoxLayout;	m->addLayout(o,1);
@@ -98,7 +98,7 @@ NewCmdDialog::NewCmdDialog(QWidget *p) : QDialog(p,Qt::WindowStaysOnTopHint)
 	connect(name, SIGNAL(currentIndexChanged(int)),this,SLOT(nameChanged(int)));
 	connect(kind, SIGNAL(currentIndexChanged(int)),this,SLOT(kindChanged(int)));
 	type->setCurrentIndex(0);	typeChanged(0);
-	setWindowTitle(tr("New command"));
+	setWindowTitle(_("New command"));
 }
 //-----------------------------------------------------------------------------
 void NewCmdDialog::zoomIn()
@@ -120,12 +120,12 @@ void NewCmdDialog::parseCmd(const QString &txt)
 		{
 			typeChanged(i);
 			name->setCurrentIndex(cmds[i].indexOf(cmd));
-			register int j,j0,k,k0;
-			bool ok;
-			for(j0=k0=-1,j=0;j<NUM_CH;j++)		// determine set of arguments
+			int j0=-1,k0=-1,k;
+			for(int j=0;j<NUM_CH;j++)		// determine set of arguments
 			{
 				if(argn[j].isEmpty())	break;
-				for(ok=true,k=0;k<argn[j].count();k++)
+				bool ok=true;
+				for(k=0;k<argn[j].count();k++)
 				{
 					a = argn[j].at(k);		opt = (a[0]=='_'  || a[0]=='+');
 					chr = (a[0]=='\'' || (opt && a[1]=='\''));
@@ -140,7 +140,7 @@ void NewCmdDialog::parseCmd(const QString &txt)
 			if(j0>=0)	// best choice
 			{
 				kind->setCurrentIndex(j0);
-				for(k=0;k<argn[j0].count();k++)
+				for(int k=0;k<argn[j0].count();k++)
 					args->item(k,1)->setText(str.section(sep,k+1,k+1).trimmed());
 			}
 			replace = true;	return;		// selection is done
@@ -163,22 +163,22 @@ void NewCmdDialog::parseCmd(const QString &txt)
 //-----------------------------------------------------------------------------
 void NewCmdDialog::fillList()
 {
-	type->addItem(QPixmap(plot_xpm), tr("1D plots"));
-	type->addItem(QPixmap(preview_xpm), tr("2D plots"));
-	type->addItem(QPixmap(":/png/weather-clouds.png"), tr("3D plots"));
-	type->addItem(QPixmap(tiles_xpm), tr("Dual plots"));
-	type->addItem(QPixmap(vect_xpm), tr("Vector plots"));
-	type->addItem(QPixmap(other_xpm), tr("Other plots"));
-	type->addItem(QPixmap(text_xpm), tr("Text and legend"));
-	type->addItem(QPixmap(table_xpm), tr("Create data and I/O"));
-	type->addItem(QPixmap(oper_dir_xpm), tr("Data transform"));
-	type->addItem(QPixmap(oper_dir_xpm), tr("Data handling"));
-	type->addItem(QPixmap(axis_xpm), tr("Axis and colorbar"));
-	type->addItem(QPixmap(axis_sh_xpm), tr("Axis setup"));
-	type->addItem(QPixmap(":/png/preferences-system.png"), tr("General setup"));
-	type->addItem(QPixmap(box_xpm), tr("Scale and rotate"));
-	type->addItem(QPixmap(":/png/media-playback-start.png"), tr("Program flow"));
-	type->addItem(QPixmap(curve_xpm), tr("Primitives"));
+	type->addItem(QPixmap(plot_xpm), _("1D plots"));
+	type->addItem(QPixmap(preview_xpm), _("2D plots"));
+	type->addItem(QPixmap(":/png/weather-clouds.png"), _("3D plots"));
+	type->addItem(QPixmap(tiles_xpm), _("Dual plots"));
+	type->addItem(QPixmap(vect_xpm), _("Vector plots"));
+	type->addItem(QPixmap(other_xpm), _("Other plots"));
+	type->addItem(QPixmap(text_xpm), _("Text and legend"));
+	type->addItem(QPixmap(table_xpm), _("Create data and I/O"));
+	type->addItem(QPixmap(oper_dir_xpm), _("Data transform"));
+	type->addItem(QPixmap(oper_dir_xpm), _("Data handling"));
+	type->addItem(QPixmap(axis_xpm), _("Axis and colorbar"));
+	type->addItem(QPixmap(axis_sh_xpm), _("Axis setup"));
+	type->addItem(QPixmap(":/png/preferences-system.png"), _("General setup"));
+	type->addItem(QPixmap(box_xpm), _("Scale and rotate"));
+	type->addItem(QPixmap(":/png/media-playback-start.png"), _("Program flow"));
+	type->addItem(QPixmap(curve_xpm), _("Primitives"));
 
 	// now fill it automatically from parser for all categories
 	long i, n = parser.GetCmdNum();
@@ -244,7 +244,7 @@ void NewCmdDialog::nameChanged(int s)
 	if(n.isEmpty())	return;
 	QStringList ss;	ss<<(pathHelp);
 	help->setSearchPaths(ss);
-	help->setSource(tr("mgl_en")+".html#"+n);
+	help->setSource(_("mgl_en")+QString(".html#")+n);
 	// clear old
 	kind->clear();	kinds.clear();	for(k=0;k<NUM_CH;k++)	argn[k].clear();
 	// try to find the keyword
@@ -307,7 +307,7 @@ void NewCmdDialog::insertData()
 	int row = args->currentRow();
 	if(row<0)
 	{
-		QMessageBox::warning(this,tr("New command"), tr("No argument is selected"));
+		QMessageBox::warning(this,_("New command"), _("No argument is selected"));
 		return;
 	}
 	QString a = args->item(row,0)->text();
@@ -321,12 +321,12 @@ void NewCmdDialog::insertData()
 	}
 	else if(a=="'file'")
 	{
-		QString str = QFileDialog::getOpenFileName(this, tr("UDAV - Insert filename"));
+		QString str = QFileDialog::getOpenFileName(this, _("UDAV - Insert filename"));
 		if(!str.isEmpty())	args->item(row,1)->setText(str);
 	}
 	else if(a=="'path'")
 	{
-		QString str = QFileDialog::getExistingDirectory(this, tr("UDAV - Insert path"));
+		QString str = QFileDialog::getExistingDirectory(this, _("UDAV - Insert path"));
 		if(!str.isEmpty())	args->item(row,1)->setText(str);
 	}
 }
@@ -335,12 +335,12 @@ void NewCmdDialog::insertStl()
 {
 	int s=kind->currentIndex();
 	if(s<0 || s>4)
-	{	QMessageBox::warning(this,tr("New command"),
-			tr("Select first the proper kind of arguments"));
+	{	QMessageBox::warning(this,_("New command"),
+			_("Select first the proper kind of arguments"));
 		return;	}
 	if(!argn[s].contains("'fmt'") && !argn[s].contains("_'fmt'"))
-	{	QMessageBox::warning(this,tr("New command"),
-			tr("There is no 'fmt' argument for this command"));
+	{	QMessageBox::warning(this,_("New command"),
+			_("There is no 'fmt' argument for this command"));
 		return;	}
 	int i;
 	i = argn[s].indexOf("'fmt'");
@@ -353,8 +353,8 @@ void NewCmdDialog::finish()
 	QString txt,cur;
 	int s = kind->currentIndex();
 	if(s<0 || s>4)
-	{	QMessageBox::warning(this,tr("New command"),
-			tr("Select first the proper kind of arguments"));
+	{	QMessageBox::warning(this,_("New command"),
+			_("Select first the proper kind of arguments"));
 		cmd="";	return;	}
 	cmd = name->currentText();
 	int n = argn[s].count(), i;
@@ -366,24 +366,24 @@ void NewCmdDialog::finish()
 		if(txt.isEmpty())
 		{
 			if(cur[0]!='_' && cur[0]!='+')
-			{	QMessageBox::warning(this,tr("New command"),
-					tr("You should specify required argument ")+cur);
+			{	QMessageBox::warning(this,_("New command"),
+					_("You should specify required argument ")+cur);
 				cmd="";	return;	}
 			if(argn[s].at(i)[0]=='_')	op = true;
 		}
 		else
 		{
 			if(cur[0]=='\'' && txt[0]!='\'')
-			{	QMessageBox::warning(this,tr("New command"),
-					tr("You should put text inside ' ' for argument ")+cur);
+			{	QMessageBox::warning(this,_("New command"),
+					_("You should put text inside ' ' for argument ")+cur);
 				cmd="";	return;	}
 			if(cur[1]=='\'' && txt[0]!='\'')
-			{	QMessageBox::warning(this,tr("New command"),
-					tr("You should put text inside ' ' for argument ")+cur.mid(1));
+			{	QMessageBox::warning(this,_("New command"),
+					_("You should put text inside ' ' for argument ")+cur.mid(1));
 				cmd="";	return;	}
 			if(cur[0]=='_' && op)
-			{	QMessageBox::warning(this,tr("New command"),
-					tr("You should specify all optional arguments before ")+cur.mid(1));
+			{	QMessageBox::warning(this,_("New command"),
+					_("You should specify all optional arguments before ")+cur.mid(1));
 				cmd="";	return;	}
 			cmd = cmd + ' ' + txt;
 		}
