@@ -1,5 +1,7 @@
 #include <stdio.h>
 #include <string.h>
+#include<mgl2/define.h>
+
 
 const char *files[] =
 {
@@ -285,6 +287,7 @@ const char *parse_name(char *name, bool &needOverload)
 		if ( 		processArgument(ptr, arg[j], "HMGL ", "%s: HMGL;")
 				||  processArgument(ptr, arg[j], "HCDT ",  "const %s: HMDT;")
 				||	processArgument(ptr, arg[j], "HMDT ",  "%s: HMDT;")
+				||	processArgument(ptr, arg[j], "mglDataA *",  "%s: HMDT;")
 				||	processArgument(ptr, arg[j], "HADT ",  "%s: HADT;")
 				||	processArgument(ptr, arg[j], "HAEX ",  "%s: HAEX;")
 				||	processArgument(ptr, arg[j], "HMPR ",  "%s: HMPR;")
@@ -294,9 +297,11 @@ const char *parse_name(char *name, bool &needOverload)
 				||	processArgument(ptr, arg[j], "mreal *",  "%s: Pmreal;")
 				||	processArgument(ptr, arg[j], "double *",  "%s: Pdouble;")
 				||	processArgument(ptr, arg[j], "char *",  "%s: PChar;")
+				||	processArgument(ptr, arg[j], "unsigned char *",  "%s: PByte;")
 				||	processArgument(ptr, arg[j], "int *", "%s: Pint;")
 				||	processArgument(ptr, arg[j], "long *",  "%s: Pint;")
 				||	processArgument(ptr, arg[j], "const char *",  "const %s: PChar;")
+				||	processArgument(ptr, arg[j], "const unsigned char *",  "const %s: PByte;")
 				||	processArgument(ptr, arg[j], "const wchar_t *",  "const %s: PWideChar;")
 				||	processArgument(ptr, arg[j], "char ",  "%s: char;")
 				||	processArgument(ptr, arg[j], "long ",  "%s: integer;")
